# Eidolon Client

[![PyPI - Downloads](https://img.shields.io/pypi/dm/eidolon-ai-client)](https://pypistats.org/packages/eidolon-ai-client)
[![Tests - Status](https://img.shields.io/github/actions/workflow/status/eidolon-ai/eidolon/test_python.yml?style=flat&label=test)](https://github.com/eidolon-ai/eidolon/actions/workflows/test_python.yml?query=branch%3Amain)

## Eidolon Client and CLI

This package contains a python client to interact with the Eidolon API. It also contains a CLI which can be called with `eidolon-cli`.
```bash
eidolon-cli --help
```

Visit [eidolonai.com](https://www.eidolonai.com/) for more details.

🚨 To install the dependencies needed for the CLI run the following command: 
```bash
pip install 'eidolon-ai-client[cli]'
```

## Thanks for your support

Eidolon is completely open source and free to use. [Star 🌟 it on GitHub](https://github.com/eidolon-ai/eidolon) to show
your support!